@@ -24,10 +24,10 @@ mod measurement_operations;
 pub use measurement_operations::*;
 mod two_qubit_gate_operations;
 pub use two_qubit_gate_operations::*;
-mod _auto_generated_operation_conversion;
-pub use _auto_generated_operation_conversion::{
-    convert_operation_to_pyobject, convert_pyany_to_operation,
-};
+include!(concat!(
+    env!("OUT_DIR"),
+    "/_auto_generated_operation_conversion.rs"
+));
 
 use pyo3::prelude::*;
 
@@ -173,6 +173,8 @@ pub fn operations(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<PMInteractionWrapper>()?;
     m.add_class::<ComplexPMInteractionWrapper>()?;
     m.add_class::<PhaseShiftedControlledZWrapper>()?;
+    m.add_class::<PhaseShiftState0Wrapper>()?;
+    m.add_class::<PhaseShiftState1Wrapper>()?;
 
     Ok(())
 }
